@@ -1,16 +1,13 @@
-from ComputedAttribute import ComputedAttribute
-from Products.CMFPlone.utils import normalizeString, safe_unicode
-
-from z3c.form.interfaces import NO_VALUE
-from zope.interface import implements
-
-from five import grok
-
-from plone.dexterity.schema import DexteritySchemaPolicy
-from plone.dexterity.content import Container
-
 from collective.contact.core.browser.contactable import Contactable
 from collective.contact.core.interfaces import IHeldPosition
+from ComputedAttribute import ComputedAttribute
+from five import grok
+from plone.dexterity.content import Container
+from plone.dexterity.schema import DexteritySchemaPolicy
+from Products.CMFPlone.utils import normalizeString
+from Products.CMFPlone.utils import safe_unicode
+from z3c.form.interfaces import NO_VALUE
+from zope.interface import implements
 
 
 def acqproperty(func):
